@@ -12,9 +12,8 @@ def check_type(actual, definition):
             return True
 
         # Both have list element definitions, so check their equality
-        return (
-            len(definition.__args__)
-            and check_type(actual.__args__[0], definition.__args__[0])
+        return len(definition.__args__) and check_type(
+            actual.__args__[0], definition.__args__[0]
         )
 
     if hasattr(definition, "__origin__") and definition.__origin__ == typing.Union:
